# Changelog

## v0.1.3 (released 2025-05-12)

### Bug fixes

- Update type hints to play nicer with mypy. [[3158627](https://github.com/NRWLDev/pydantic-db/commit/31586270ef99a581628c6c8959e3775451cab3c3)]

## v0.1.2 (released 2025-05-12)

### Bug fixes

- Drop documentation link from pypi. [[f1627de](https://github.com/NRWLDev/pydantic-db/commit/f1627de934151cdd05000d89b9e79033eb68dbeb)]

## v0.1.1 (released 2025-05-12)

### Bug fixes

- Add py.typed for type checkers. [[ed12f79](https://github.com/NRWLDev/pydantic-db/commit/ed12f79ff1a92f33e75b080270a566e5363cace1)]

## v0.1.0 (released 2025-05-12)

### Features and Improvements

- Add support for extracting columns and types from a model. [[f4178ae](https://github.com/NRWLDev/pydantic-db/commit/f4178ae54efffffe65da50718fffb389a21a4977)]
- Add support for nested models [[998ab19](https://github.com/NRWLDev/pydantic-db/commit/998ab191d07afaba9ad12b69671b875227a63620)]
- Basic database model mapping for result and list of results. [[f007a01](https://github.com/NRWLDev/pydantic-db/commit/f007a012c97b7b4c00eebcb1503035408e74c267)]

### Miscellaneous

- Expand tests to confirm support for sqlite [[b40c806](https://github.com/NRWLDev/pydantic-db/commit/b40c806fdb2531deece4e195f0f5eb77fea29596)]
- Expand test coverage [[b69fbe0](https://github.com/NRWLDev/pydantic-db/commit/b69fbe09a9f1f0097b53c3fa6acd77e946602d8c)]
